 /*
 * file      : build.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>
#include <string.h>

#include "../lib_basebuild/libbasebuild.h"

#include "win_vte.h"
#include "def_src.h"
#include "win_info.h"
#include "configuser.h"
#include "proto.h"
#include "build.h"
#include "conv.h"
#include "callbacks.h"
#include "global.h"



VAR_BUILD VarBuild;
extern VAR_PROTO VarProto;



// FREE ALLOCATIONS
// 
void build_remove (void)
{
	VarBuild.ListPathSrc = DefSrc_remove_list (VarBuild.ListPathSrc);
	
	if (NULL != VarBuild.PathProject) {
		g_free (VarBuild.PathProject);
		VarBuild.PathProject = NULL;
	}
	if (NULL != VarBuild.NameProject) {
		g_free (VarBuild.NameProject);
		VarBuild.NameProject = NULL;
	}
	if (NULL != VarBuild.NameLib) {
		g_free (VarBuild.NameLib);
		VarBuild.NameLib = NULL;
	}
	if (NULL != VarBuild.VersionProject) {
		g_free (VarBuild.VersionProject);
		VarBuild.VersionProject = NULL;
	}
	if (NULL != VarBuild.NewPathName) {
		g_free (VarBuild.NewPathName);
		VarBuild.NewPathName = NULL;
	}
	if (NULL != VarBuild.PathNameLib) {
		g_free (VarBuild.PathNameLib);
		VarBuild.PathNameLib = NULL;
	}
	if (NULL != VarBuild.PathNameMan) {
		g_free (VarBuild.PathNameMan);
		VarBuild.PathNameMan = NULL;
	}
	if (NULL != VarBuild.PathNamePo) {
		g_free (VarBuild.PathNamePo);
		VarBuild.PathNamePo = NULL;
	}
	if (NULL != VarBuild.PathNamePixmaps) {
		g_free (VarBuild.PathNamePixmaps);
		VarBuild.PathNamePixmaps = NULL;
	}
	if (NULL != VarBuild.PathNameMenu) {
		g_free (VarBuild.PathNameMenu);
		VarBuild.PathNameMenu = NULL;
	}
	if (NULL != VarBuild.PathNameMime) {
		g_free (VarBuild.PathNameMime);
		VarBuild.PathNameMime = NULL;
	}
	if (NULL != VarBuild.PathNameGlade) {
		g_free (VarBuild.PathNameGlade);
		VarBuild.PathNameGlade = NULL;
	}
}
//
//
gchar *build_get_dest_pathnamefile_glade (void)
{	
	return( g_strdup_printf( "%s/%s.glade", VarBuild.PathNameGlade, VarBuild.NameProject ));
}
// ALLOCATIONS OPTIONS
// 
void build_init (void)
{
	VAR_BUILD_SRC	*DefSrc = NULL;
	GList		*List = NULL;
	gchar		*PtrLib = NULL;
	
	// FREE ALLOCATIONS
	build_remove ();
	
	VarBuild.ListPathSrc     = DefSrc_get_list ();
	VarBuild.PathProject     = g_strdup (gtk_button_get_label (GTK_BUTTON (VarBB.Adr_button_path)));
	VarBuild.NameProject     = g_strdup (gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project)));
	VarBuild.VersionProject  = g_strdup_printf ("%d.%d.%d",
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_A)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_B)),
					gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_C))
					);
	VarBuild.NewPathName     = g_strdup_printf ("%s/%s-%s", VarBuild.PathProject, VarBuild.NameProject, VarBuild.VersionProject);
	
	PtrLib = (gchar *)gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_library));
	if ('\0' == *PtrLib) {
		VarBuild.NameLib = g_strdup ("lib");
	}
	else {
		VarBuild.NameLib = g_strdup (PtrLib);
	}
	VarBuild.PathNameLib = g_strdup_printf ("%s/%s", VarBuild.NewPathName, VarBuild.NameLib);
	
	List = g_list_first (VarBuild.ListPathSrc);
	while (List) {
		if (NULL != (DefSrc = (VAR_BUILD_SRC *)List->data)) {
			DefSrc->PathName          = g_strdup_printf ("%s/%s", VarBuild.NewPathName, DefSrc->Name);
		}
		List = g_list_next (List);
	}
	
	VarBuild.PathNameMan     = g_strdup_printf ("%s/man", VarBuild.NewPathName);
	VarBuild.PathNamePo      = g_strdup_printf ("%s/po", VarBuild.NewPathName);
	VarBuild.PathNamePixmaps = g_strdup_printf ("%s/pixmaps", VarBuild.NewPathName);
	VarBuild.PathNameMenu    = g_strdup_printf ("%s/menu", VarBuild.NewPathName);
	VarBuild.PathNameMime    = g_strdup_printf ("%s/mime", VarBuild.NewPathName);
	VarBuild.PathNameGlade   = g_strdup_printf ("%s/glade", VarBuild.NewPathName);
	
	VarBuild.Bool_lib_gtk			= FALSE;
	if( TRUE == Config.BoolRadioButonGui )
		VarBuild.Bool_lib_gtk		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_lib_gtk")));
	VarBuild.Bool_lib_glib			= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_lib_glib")));
	// SELECTION OBLIGAOIRE
	if( TRUE == Config.BoolRadioButonGui && FALSE == VarBuild.Bool_lib_gtk && FALSE == VarBuild.Bool_lib_glib ) {
		VarBuild.Bool_lib_gtk = TRUE;
	}
		
	VarBuild.Bool_dossier_glade		= FALSE;
	if( TRUE == Config.BoolRadioButonGui )
		VarBuild.Bool_dossier_glade	= Config.ComboboxChoiceGlade > CHOICE_GLADE_FILE_NONE ? TRUE : FALSE;
	VarBuild.Bool_dossier_po		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_po")));
	VarBuild.Bool_dossier_manpage		= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_manpage")));
	VarBuild.Bool_dossier_lib_statique	= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_lib_statique")));
	VarBuild.Bool_dossier_pixmaps		= FALSE;
	if( TRUE == Config.BoolRadioButonGui )
		VarBuild.Bool_dossier_pixmaps	= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")));
	VarBuild.Bool_dossier_menu		= FALSE;
	if( TRUE == Config.BoolRadioButonGui )
		VarBuild.Bool_dossier_menu	= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu")));
	VarBuild.Bool_dossier_mime		= FALSE;
	if( TRUE == Config.BoolRadioButonGui )
		VarBuild.Bool_dossier_mime	= gtk_toggle_button_get_active ( GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_mime")));
	
	VarBuild.Bool_import_glade_file         = FALSE;
	VarBuild.Bool_import_glade_translate    = FALSE;
}
// 
// 
gboolean build_pthread( void )
{
	gchar		*LineCommand = NULL;
	gint		RetSystem = -2;
	GList		*List = NULL;
	VAR_BUILD_SRC	*VarBuildSrc = NULL;
	gchar		*PathNamePotfile = NULL;
	gchar		*PathNameAutoscanLog = NULL;
	FILE		*fp = NULL;
	gchar		*TmpActuel = g_get_current_dir ();
	
	// PRINT_FUNC_LF();
	
	build_init ();

	if( TRUE == Config.BoolRadioButonGui ) {
	
	}
	
	WinVte_reset();
	WinVte_window_write_va ("\nCREATION DU PROJET  [ ", VarBuild.NameProject, "-", VarBuild.VersionProject, " ]\n\n", NULL);
	
	// SUPPRESSION DU DOSSIER SI IL EXISTE
	if (g_file_test (VarBuild.NewPathName, G_FILE_TEST_IS_DIR)) {
		if (NULL != (LineCommand = g_strdup_printf ("rm -rf %s", VarBuild.NewPathName))) {
			WinVte_window_write_va ("SUPPRESSION DE L ANCIEN DOSSIER:\n\t", VarBuild.NewPathName, "\n", NULL);
			RetSystem = system( LineCommand );
			g_free (LineCommand);
			LineCommand = NULL;
		}
	}
	
	// CREATION DOSSIER DU PROJET
	WinVte_window_write_va ("CREATION DOSSIER DU PROJET:\n\t", VarBuild.NewPathName, "\n", NULL);
	g_mkdir_with_parents (VarBuild.NewPathName, 0700);
	
	// CREATION FICHIER Makefile.am
	WinVte_window_write_va ("\t", VarBuild.NewPathName, "/Makefile.am\n", NULL);
	BuildWrite_makefile_am( VarBuild.NewPathName, "Makefile", ".am" );
	
	// LES DOSSIERS LIBRAIRIE STATIQUE
	if (TRUE == VarBuild.Bool_dossier_lib_statique) {
		WinVte_window_write_va ("CREATION DOSSIER LIBRAIRIE STATIQUE:\n\t", VarBuild.PathNameLib, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNameLib, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_lib_makefile_am( VarBuild.PathNameLib, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNameLib, "/Makefile.am\n", NULL);
		// CREATION FICHIER lib/lib.c lib/lib.h
		WinVte_window_write_va ("\t", VarBuild.PathNameLib, "/lib.c\n", NULL);
		WinVte_window_write_va ("\t", VarBuild.PathNameLib, "/lib.h\n", NULL);
		BuildWrite_LIB_H_file( VarBuild.PathNameLib, "lib", ".h" );
		BuildWrite_LIB_C_file( VarBuild.PathNameLib, "lib", ".c" );
	}

	// CREATE DOSSIER GLADE
	if (TRUE == VarBuild.Bool_dossier_glade) {
		WinVte_window_write_va ("CREATION DOSSIER GLADE:\n\t", VarBuild.PathNameGlade, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNameGlade, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_glade_makefile_am( VarBuild.PathNameGlade, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNameGlade, "/Makefile.am\n", NULL);
		// CREATION FICHIER glade.glade
		WinVte_window_write_va ("\t", VarBuild.PathNameGlade, "/", VarBuild.NameProject, ".glade\n", NULL);
		BuildWrite_GLADE_file( VarBuild.PathNameGlade, VarBuild.NameProject, ".glade" );
		if( TRUE == VarBuild.Bool_dossier_po ) {
			VarBuild.Bool_import_glade_file         = TRUE;
			VarBuild.Bool_import_glade_translate    = TRUE;
		}
	}

	// CREATE DOSSIER SRC
	List = g_list_first (VarBuild.ListPathSrc);
	while (List) {
		if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
			// CREATE DOSSIER SRC	
			WinVte_window_write_va ("CREATION DOSSIER SOURCE:\n\t", VarBuildSrc->PathName, "\n", NULL);
			g_mkdir_with_parents (VarBuildSrc->PathName, 0700);
			// CREATION FICHIER Makefile.am
			WinVte_window_write_va ("\t", VarBuildSrc->PathName, "/Makefile.am\n", NULL);
			BuildWrite_src_makefile_am( VarBuildSrc->PathName, "Makefile", ".am", VarBuildSrc );
			// CREATION FICHIER src.../main.c
			WinVte_window_write_va ("\t", VarBuildSrc->PathName, "/main.c\n", NULL);
			BuildWrite_SRC_C_file( VarBuildSrc->PathName, "main", ".c", VarBuildSrc );
			BuildWrite_GLOBAL_H_file( VarBuildSrc->PathName, "global", ".h" );
			BuildWrite_SRC_TRANSLATE_C_file( VarBuildSrc->PathName, "translate", ".c", VarBuildSrc );
			
		}
		List = g_list_next (List);
	}
	
	// CREATE DOSSIER PO
	if (TRUE == VarBuild.Bool_dossier_po) {
		WinVte_window_write_va ("CREATION DOSSIER INTERNATIONALISATION:\n\t", VarBuild.PathNamePo, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNamePo, 0700);
	}
	
	// CREATE DOSSIER MANPAGE
	if (TRUE == VarBuild.Bool_dossier_manpage) {
		WinVte_window_write_va ("CREATION DOSSIER MANPAGE:\n\t", VarBuild.PathNameMan, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNameMan, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_man_makefile_am( VarBuild.PathNameMan, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNameMan, "/Makefile.am\n", NULL);
		// CREATION FICHIER man.1.gz
		WinVte_window_write_va ("\t", VarBuild.PathNameMan, "/", VarBuild.NameProject, ".1.gz\n", NULL);
		BuildWrite_MAN_file();
	}
	
	// CREATE DOSSIER PIXMAPS
	if (TRUE == VarBuild.Bool_dossier_pixmaps) {
		WinVte_window_write_va ("CREATION DOSSIER PIXMAPS:\n\t", VarBuild.PathNamePixmaps, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNamePixmaps, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_pixmaps_makefile_am( VarBuild.PathNamePixmaps, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNamePixmaps, "/Makefile.am\n", NULL);
		// CREATION FICHIER pixmaps/testbasebuild.png
		WinVte_window_write_va ("\t", VarBuild.PathNamePixmaps, "/test", VarBuild.NameProject, ".png\n", NULL);
		BuildWrite_PIXMAPS_file();
	}
	
	// CREATE DOSSIER MENU
	if (TRUE == VarBuild.Bool_dossier_menu) {
		WinVte_window_write_va ("CREATION DOSSIER MENU:\n\t", VarBuild.PathNameMenu, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNameMenu, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_menu_makefile_am( VarBuild.PathNameMenu, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNameMenu, "/Makefile.am\n", NULL);
		// CREATION FICHIER menu.menu
		WinVte_window_write_va ("\t", VarBuild.PathNameMenu, "/", VarBuild.NameProject, ".desktop\n", NULL);
		BuildWrite_MENU_file( VarBuild.PathNameMenu, VarBuild.NameProject, ".desktop" );
	}
	
	// CREATE DOSSIER MIME
	if (TRUE == VarBuild.Bool_dossier_mime) {
		WinVte_window_write_va ("CREATION DOSSIER MIME:\n\t", VarBuild.PathNameMime, "\n", NULL);
		g_mkdir_with_parents (VarBuild.PathNameMime, 0700);
		// CREATION FICHIER Makefile.am
		BuildWrite_mime_makefile_am( VarBuild.PathNameMime, "Makefile", ".am" );
		WinVte_window_write_va ("\t", VarBuild.PathNameMime, "/Makefile.am\n", NULL);
		// CREATION FICHIER mime.mime
		WinVte_window_write_va ("\t", VarBuild.PathNameMime, "/", VarBuild.NameProject, "\n", NULL);
		BuildWrite_MIME_file( VarBuild.PathNameMime, VarBuild.NameProject, "" );
	}
		
	// SE PLACER DANS LE DOSSIER VarBuild.NewPathName/
	g_chdir (VarBuild.NewPathName);
		
	// CREATION FICHIER configure.in
	WinVte_window_write_va ("CREATION FICHIER:\n\t", VarBuild.NewPathName, "/configure.in\n", NULL);
	BuildWrite_configure_in( VarBuild.NewPathName, "configure", ".in" );
	
	// MODIFICATION DOSSIER PO
	if (TRUE == VarBuild.Bool_dossier_po) {
				
		// POUR OUTREPASSER GETTEXTIZE
		// http://culot.org/public/Docs/autotools.html
		WinVte_window_write_va ("OUTREPASSER\n\tgettextize AVEC /tmp/my-gettextize.sh\n", NULL);
		BuildWrite_GETTEXTIZE_file();
		
		// gettextize copie tous les fichiers standards Gettext dans le répertoire principal d'un package, pour commencer sa traduction.
		// Prise en compte de l'internationalisation qui modifie 'configure.in' et 'Makefile.am'
		// 	$ gettextize -c
		// Le fichier ./ABOUT-NLS sera cree
		WinVte_window_write_va ("EXEC\n\t/tmp/my-gettextize.sh -c\n", NULL);
		conv_with_args( "/tmp/my-gettextize.sh", "-c", NULL );
		
		WinVte_window_write_va ("SUPPRESSION DE:\n\t/tmp/set-gettextize.sh\n\t/tmp/my-gettextize.sh\n", NULL);
		g_unlink ("/tmp/set-gettextize.sh");
		g_unlink ("/tmp/my-gettextize.sh");
		
		// RENOMMER 'Makevars.template' vers 'po/Makevars'
		{
			gchar	*OldFile = g_strdup_printf ("%s/Makevars.template", VarBuild.PathNamePo);
			gchar	*NewFile = g_strdup_printf ("%s/Makevars", VarBuild.PathNamePo);
			WinVte_window_write_va ("RENOMMER:\n\t", OldFile, "\n\t", NewFile, "\n", NULL);
			g_rename(OldFile, NewFile);
			g_free (OldFile);
			OldFile = NULL;
			g_free (NewFile);
			NewFile = NULL;
		}
		
		// ADAPTATION DE 'po/POTFILES.in'
		{
			GString	*GstrPot = NULL;
			GList	*List = NULL;
		
			PathNamePotfile = g_strdup_printf ("%s/POTFILES.in", VarBuild.PathNamePo);
			if (NULL != (fp = fopen (PathNamePotfile,"a"))) {
				WinVte_window_write_va ("AJOUTER A:\n\t", PathNamePotfile, "\n", NULL);
				GstrPot = g_string_new (NULL);
				List = g_list_first (VarBuild.ListPathSrc);
				while (List) {
					if (NULL != (VarBuildSrc = (VAR_BUILD_SRC *)List->data)) {
						g_string_append_printf (GstrPot, "%s/main.c\n", VarBuildSrc->Name);
						WinVte_window_write_va ("\t", VarBuildSrc->Name, "/main.c\n", NULL);
						if( NULL != VarProto.GstrTranslate ) {
							g_string_append_printf (GstrPot, "%s/translate.c\n", VarBuildSrc->Name);
							WinVte_window_write_va ("\t", VarBuildSrc->Name, "/translate.c\n", NULL);
						}
					}
					List = g_list_next (List);
				}
				g_fprintf (fp, "%s", GstrPot->str);
				fclose (fp);
			
			}
			g_string_free (GstrPot, TRUE);
		}

		// RE CREATION FICHIER configure.in
		BuildWrite_configure_in( VarBuild.NewPathName, "configure", ".in" );
		
		// RE CREATION FICHIER Makefile.am
		BuildWrite_makefile_am( VarBuild.NewPathName, "Makefile", ".am" );
				
		// CREATION
		// 	po/en.po
		//	po/fr.po
		//	po/de.po
		//	po/it.po
		PathNamePotfile = g_strdup_printf ("%s/en.po\n\t%s/fr.po\n\t%s/de.po\n\t%s/it.po\n\t", VarBuild.PathNamePo, VarBuild.PathNamePo, VarBuild.PathNamePo, VarBuild.PathNamePo);
		WinVte_window_write_va ("CREATION FICHIER:\n\t", PathNamePotfile, "\n", NULL);
		g_free (PathNamePotfile);
		PathNamePotfile = NULL;	
		BuildWrite_PO_file( VarBuild.PathNamePo );
	}
	
	// CREATION FICHIERS ./NEWS ./README ./AUTHORS ./ChangeLog
	WinVte_window_write_va ("CREATION FICHIERS:\n\t",
					VarBuild.NewPathName, "/NEWS\n\t",
					VarBuild.NewPathName, "/README\n\t",
					VarBuild.NewPathName, "/AUTHORS\n\t",
					VarBuild.NewPathName, "/ChangeLog\n",
					NULL);
	BuildWrite_file( VarBuild.NewPathName, "NEWS", "", NULL );
	BuildWrite_file( VarBuild.NewPathName, "README", "", NULL );
	BuildWrite_file( VarBuild.NewPathName, "AUTHORS", "", NULL );
	BuildWrite_file( VarBuild.NewPathName, "ChangeLog", "", NULL );
	
	// CONSTRUCTION DU PAQUET
	WinVte_window_write_va ("EXEC\n\tautoscan\n", NULL);
	conv_with_args( "autoscan", NULL );
	
	WinVte_window_write_va ("\taclocal\n", NULL);
	conv_with_args( "aclocal", NULL );
	
	WinVte_window_write_va ("\tautoheader\n", NULL);
	conv_with_args( "autoheader", NULL );
	
	WinVte_window_write_va ("\tautoconf\n", NULL);
	conv_with_args( "autoconf", NULL );
	
	WinVte_window_write_va ("\tautomake -a -c\n", NULL);
	conv_with_args( "automake", "-a", "-c", NULL );
	
	WinVte_window_write_va ("\tautomake --add-missing\n", NULL);
	conv_with_args( "automake", "--add-missing", NULL );
	
	WinVte_window_write_va ("\tautomake\n", NULL);
	conv_with_args( "automake", NULL );
	
	WinVte_window_write_va ("\t./configure --prefix=/usr\n", NULL);
	conv_with_args( "./configure", "--prefix=/usr", NULL );
	
	WinVte_window_write_va ("\tmake\n", NULL);
	conv_with_args( "make", NULL );
	
	WinVte_window_write_va ("\tmake distcheck\n", NULL);
	conv_with_args( "make", "distcheck", NULL );

	// SE REPLACER DANS LE DOSSIER D ORIGINE
	g_chdir (TmpActuel);
	g_free (TmpActuel);
	TmpActuel = NULL;
	
	// ACTIVATION APRES LA GENERATION DU PROJET
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("menubar1")), TRUE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("notebook_general")), TRUE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("hbox1")), TRUE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("vbox7")), TRUE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_gen_projet")), TRUE);
		
	WinVte_window_write_va ("\n********************\n\n",
			  NULL);
	
	PathNameAutoscanLog = g_strdup_printf( "%s/autoscan.log", VarBuild.NewPathName );
	if( TRUE == libutils_test_file_exist( PathNameAutoscanLog )) {
		WinVte_window_write_va (
			_("LE FICHIER"),
			  "\n\t",
			  VarBuild.NewPathName,
			  "/configure.in",
			  "\n",
			_("DOIT ETRE COMPLETE DEPUIS LE FICHIER"),
			  "\n\t",
			  VarBuild.NewPathName,
			  "/autoscan.log",
			  "\n",
			  "\n********************\n\n",
			  NULL);
	}
	g_free( PathNameAutoscanLog );
	PathNameAutoscanLog = NULL;
	
	WinVte_window_write_va (
			_("VOTRE PAQUET EST DISPONIBLE DEPUIS LE DOSSIER:"),
			  "\n\t",
			  VarBuild.NewPathName,
			  "\n",
			  NULL);
	if (TRUE == ProtoTranslate_contains_accents ()) {
		WinVte_window_write_va ("\n",
				  "\t",
				  _("*** ERREUR A CORRIGER DANS LE FICHIER DE TRADUCTION:"),
				  "\n\t",
				  _("***   IL CONTIENT DES ACCENTS"),
				  "\n",
				  NULL);
	}
	WinVte_window_write_va ("\n********************\n",
			  NULL);
	
	// FREE ALLOCATIONS
	Proto_remove ();
	build_remove ();
	
	return( FALSE );
}
// 
// 
void build_clicked( void )
{
	GString		*Gstr = g_string_new (NULL);
	gboolean	 BoolErr = FALSE;
	
	PRINT_FUNC_LF();
	
	WinVte_reset();
	
	switch (DefSrc_is_dupply ()) {
	case 0 :
		break;
	case 1 :
		WinVte_window_write_va (_("Mauvaise orthographe !\n\tLe nom n'est pas au standard GNU\n\tVeuillez corriger\n"), NULL);
		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_dossiers")), 1);
		return;
	case 2 :
		WinVte_window_write_va (_("Dupplication de noms de dossiers sources !\n\tLes noms des dossiers sources ne doivent pas etre identiques\n\tVeuillez corriger\n"), NULL);
		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_dossiers")), 1);
		return;
	case 3 :
		WinVte_window_write_va (_("Dupplication de noms de dossiers ET mauvaise orthographe !\n\tVeuillez corriger\n"), NULL);
		gtk_notebook_set_current_page (GTK_NOTEBOOK (GLADE_GET_OBJECT("notebook_dossiers")), 1);
		return;
	}
		
	// TEST PRESENCE DES PROGRAMMES EXTERNES
	if (FALSE == libutils_find_file ("gettextize") && TRUE == VarBuild.Bool_dossier_po) {
		g_string_append_printf (Gstr, "\t<b>gettextize</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoscan")) {
		g_string_append_printf (Gstr, "\t<b>autoscan</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("aclocal")) {
		g_string_append_printf (Gstr, "\t<b>aclocal</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoheader")) {
		g_string_append_printf (Gstr, "\t<b>autoheader</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("autoconf")) {
		g_string_append_printf (Gstr, "\t<b>autoconf</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("automake")) {
		g_string_append_printf (Gstr, "\t<b>automake</b>\n");
		BoolErr = TRUE;
	}
	if (FALSE == libutils_find_file ("make")) {
		g_string_append_printf (Gstr, "\t<b>make</b>\n");
		BoolErr = TRUE;
	}
	if (TRUE == BoolErr) {
		build_remove ();
		wininfo_create (
			WindMain,
			_("Applications absentes !"),
			_("   Applications a installer :            "),
			  "\n\n",
			  Gstr->str,
			  "\n",
			  "");
		
		g_string_free (Gstr, TRUE);
		Gstr = NULL;
		return;
	}
	g_string_free (Gstr, TRUE);
	Gstr = NULL;
	
	// DEACTIVATION AVANT LA GENERATION DU PROJET
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("menubar1")), FALSE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("notebook_general")), FALSE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("hbox1")), FALSE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("vbox7")), FALSE);
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_gen_projet")), FALSE);
	// THREAD
	g_idle_add( (GSourceFunc)build_pthread, NULL );
}















