 /*
 * file      : callbacks.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_basebuild/libbasebuild.h"
#endif

#include "configuser.h"
#include "fileselect.h"
#include "win_info.h"
#include "proto.h"
#include "build.h"
#include "callbacks.h"
#include "global.h"



VAR_BB		VarBB;
VAR_BUILD_SRC	*VarBuildSrc = NULL;


// TYPE PROJECT: GUI
// 
void on_radiobutton_gui_realize( GtkWidget *widget, gpointer user_data )
{
	if( TRUE == Config.BoolRadioButonGui )
		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (widget), Config.BoolRadioButonGui );
}
// TYPE PROJECT: LINE COMMAND
// 
void on_radiobutton_command_line_realize( GtkWidget *widget, gpointer user_data )
{
	if( FALSE == Config.BoolRadioButonGui )
		gtk_toggle_button_set_active ( GTK_TOGGLE_BUTTON (widget), TRUE );
}


// SWITCH PAGE
// 
void on_notebook_general_switch_page( GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data )
{
	if (TRUE == Config.BoolConfigOk) {
		Config.Page = page_num;
	}
}


// PROJECT IDENTITY
// 
void on_button_path_projet_realize (GtkWidget *widget)
{
	VarBB.Adr_button_path = GTK_BUTTON (widget);
	gtk_button_set_use_underline (GTK_BUTTON (widget), FALSE);
	gtk_button_set_label (GTK_BUTTON (widget), Config.PathDest);
}
void file_select_new_path_destination (gchar *path)
{
	if (FALSE == libutils_test_write (path)) {

		wininfo_create (
			WindMain,
			_("Erreur choix lieu de stockage !"),
			_("   Le lieu de stockage temporaire doit pouvoir     "),
			  "\n",
			_("   etre accessible en ecriture."),
			  "\n\n",
			_("   Veuillez recommencer."),
			  "\n",
			  "");

		return;
	}
	g_free (Config.PathDest);
	Config.PathDest = NULL;
	Config.PathDest = g_strdup (path);
	gtk_button_set_use_underline (GTK_BUTTON (VarBB.Adr_button_path), FALSE);
	gtk_button_set_label (GTK_BUTTON (VarBB.Adr_button_path), Config.PathDest);
}
void on_button_path_projet_clicked( GtkButton *button, gpointer user_data )
{
	fileselect( _("Choix du dossier pour le projet"), TRUE, file_select_new_path_destination, Config.PathDest );
}
gchar *Callbacks_get_name_project( void )
{
	gchar	*NameLib = NULL;
	gchar	*Ptr = NULL;
	
	if( NULL != VarBB.Adr_name_project ) {
		NameLib = g_strdup( (gchar *)gtk_entry_get_text( GTK_ENTRY(VarBB.Adr_name_project)));
		Ptr = NameLib;
		while( *Ptr ) {
			if( ' ' == *Ptr || '\t' == *Ptr || '-' == *Ptr ) {
				strcpy( Ptr, (Ptr +1));
			}
			else Ptr ++;
		}
	}
	return( (gchar *) NameLib );
}
void Callbacks_set_name_to_entry_lib( void )
{
	if( NULL != VarBB.Adr_name_project && NULL != VarBB.Adr_name_library) {
		
		gchar	*NameLib = NULL;
		
		if( '\0' != gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project))) {
			
			gchar	*NameProject = Callbacks_get_name_project();
			NameLib = g_strdup_printf ("lib_%s", NameProject );
			g_free( NameProject );	NameProject = NULL;
		}
		else {
			NameLib = g_strdup ("lib");
		}
		gtk_entry_set_text (GTK_ENTRY (VarBB.Adr_name_library), NameLib);
	
		g_free (NameLib);
		NameLib = NULL;
	}
}
void on_entry_name_projet_changed( GtkEditable *editable, gpointer user_data )
{
	if (NULL != VarBB.Adr_name_project) {
		g_free (Config.NameProject);
		Config.NameProject = NULL;
		Config.NameProject = g_strdup( gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project)));
		
		// SET NAME IN ENTRY-LIB
		Callbacks_set_name_to_entry_lib();
		
		// ACTIVATION / DESACTIVATION DU BOUTON [ GENERAION DU PROJET ]
		gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_gen_projet")),
			('\0' == *gtk_entry_get_text (GTK_ENTRY (VarBB.Adr_name_project))) ? FALSE : TRUE);
	}
}
void on_entry_name_projet_realize( GtkWidget *widget, gpointer user_data )
{
	if ('\0' == *Config.NameProject) {
		g_free (Config.NameProject);
		Config.NameProject = NULL;
		Config.NameProject = g_strdup ("NameProject");
	}
	gtk_entry_set_text (GTK_ENTRY (widget), Config.NameProject);
	VarBB.Adr_name_project = widget;
	Callbacks_set_name_to_entry_lib();
}
void on_spinbutton_version_A_realize (GtkWidget *widget, gpointer user_data)
{
	VarBB.Adr_spinbutton_version_A = widget;
	gtk_spin_button_set_value (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_A), (gdouble)Config.Version_A);
}
void on_spinbutton_version_B_realize (GtkWidget *widget, gpointer user_data)
{
	VarBB.Adr_spinbutton_version_B = widget;
	gtk_spin_button_set_value (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_B), (gdouble)Config.Version_B);
}
void on_spinbutton_version_C_realize (GtkWidget *widget, gpointer user_data)
{
	VarBB.Adr_spinbutton_version_C = widget;
	gtk_spin_button_set_value (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_C), (gdouble)Config.Version_C);
}
void on_spinbutton_version_changed( GtkWidget *widget, gpointer user_data )
{
	if (NULL != VarBB.Adr_spinbutton_version_A && NULL != VarBB.Adr_spinbutton_version_B && NULL != VarBB.Adr_spinbutton_version_C) {
		Config.Version_A = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_A));
		Config.Version_B = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_B));
		Config.Version_C = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON(VarBB.Adr_spinbutton_version_C));
	}
}

void on_checkbutton_dossier_po_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepPO );	
}
void on_checkbutton_dossier_manpage_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepMANPAGE );	
}
void on_checkbutton_dossier_lib_statique_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepLIBSTATIQUE );	
}
void on_checkbutton_dossier_pixmaps_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepPIXMAPS );	
}
void on_checkbutton_dossier_menu_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepMENU );	
}
void on_checkbutton_dossier_mime_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(widget), Config.BoolCheckbuttonRepMIME );
}
void on_checkbutton_REP_clicked( GtkButton *button, gpointer user_data )
{
	// WITH CTRL PRESSED: ALL SELECTED
	if( TRUE == keys.BoolGDK_Control_L_R ) {
		// PRINT( "WITH CTRL PRESSED: ALL SELECTED" );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_po")), TRUE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_manpage")), TRUE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_lib_statique")), TRUE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")), TRUE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_menu")), TRUE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_mime")), TRUE );
	} 
	// WITH SHIFT PRESSED: ALL DESELECTED
	else if( TRUE == keys.BoolGDK_Shift_L || TRUE == keys.BoolGDK_Shift_R ) {
		// PRINT( "WITH SHIFT PRESSED: ALL DESELECTED" );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_po")), FALSE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_manpage")), FALSE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_lib_statique")), FALSE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")), FALSE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_menu")), FALSE );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_dossier_mime")), FALSE );
	}
	else {
		if( TRUE == Config.BoolRadioButonGui ) {
			if (button == GTK_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu"))) {
				if (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu")))) {
					gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")), TRUE);
				}
			}
			else if (button == GTK_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_pixmaps"))) {
				if (FALSE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_pixmaps"))) &&
					TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu")))) {
					gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu")), FALSE);
				}
			}
		}
	}
	if( TRUE == Config.BoolRadioButonGui ) {
	 	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_categories_menu")), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu"))));
	 	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_categories_mime")), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_mime"))));
	 }
}
void on_checkbutton_LIB_clicked( GtkButton *button, gpointer user_data )
{
	// WITH CTRL PRESSED: ALL SELECTED
	if( TRUE == keys.BoolGDK_Control_L_R ) {
		// PRINT( "WITH CTRL PRESSED: ALL SELECTED" );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_gtk")), TRUE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_glib")), TRUE );
	} 
	// WITH SHIFT PRESSED: ALL DESELECTED
	else if( TRUE == keys.BoolGDK_Shift_L || TRUE == keys.BoolGDK_Shift_R ) {
		// PRINT( "WITH SHIFT PRESSED: ALL DESELECTED" );
		if( TRUE == Config.BoolRadioButonGui )
			gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_gtk")), FALSE );
		gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_glib")), FALSE );
	}
	else if (button == GTK_BUTTON (GLADE_GET_OBJECT("checkbutton_lib_gtk"))) {
		if( TRUE == gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_gtk")))) {
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_glade")), TRUE );
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), Config.ComboboxChoiceGlade <= CHOICE_GLADE_FILE_DEFAULT ? FALSE : TRUE );
		}
		else {
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_glade")), FALSE );
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), FALSE );
		}
	}
}
void on_entry_name_static_lib_realize( GtkWidget *widget, gpointer user_data )
{
	VarBB.Adr_name_library = widget;
	Callbacks_set_name_to_entry_lib();
}
void on_combobox_categories_menu_realize( GtkWidget *widget, gpointer user_data )
{
	VarBB.Adr_combobox_categories = GTK_COMBO_BOX (widget);

	libcombo_alloc (GTK_COMBO_BOX (VarBB.Adr_combobox_categories));
	
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "AudioVideo");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Audio");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Video");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Development");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Education");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Game");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Graphics");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Network");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Office");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Settings");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "System");
	gtk_combo_box_append_text (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), "Utility");
	
	gtk_combo_box_set_active (GTK_COMBO_BOX (VarBB.Adr_combobox_categories), 3);
}

void on_combobox_categories_mime_realize( GtkWidget *widget, gpointer user_data )
{
	// VarBB.Adr_combobox_categories = GTK_COMBO_BOX (widget);

	libcombo_alloc (GTK_COMBO_BOX (widget));
	
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Texte"));
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Audio"));
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Video"));
	
	gtk_combo_box_set_active (GTK_COMBO_BOX (widget), 0);
}

void on_button_gen_projet_clicked( GtkButton *button, gpointer user_data )
{
	build_clicked();
}


// 
// AFFICHAGE DES TRADUCTIONS POUR LE FICHIER GLADE
// 
void on_button_name_file_glade_realize( GtkWidget *widget, gpointer user_data )
{
	gchar	*Str = g_strdup_printf( "%s/%s", Config.PathGlade, Config.NameFileGlade );
	
	if (NULL == Config.PathGlade)		Config.PathGlade = getenv ("HOME");
	if (NULL == Config.NameFileGlade)	Config.NameFileGlade = g_strdup ("");
	
	gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_name_file_glade")), Str );
	g_free( Str );	Str = NULL;
}
// 
// VERIF IF PathNameGladeFile IS A GLADE FILE
// 
gboolean Callbacks_is_glade_file( gchar *PathNameGladeFile )
{	
	/*
	<?xml version="1.0"?>
	<interface>

	<?xml version="1.0" standalone="no"?> <!--*- mode: xml -*-->
	<!DOCTYPE glade-interface SYSTEM "http://glade.gnome.org/glade-2.0.dtd">
	<glade-interface>
	*/
	gboolean	BoolFileIsGlade = FALSE;
#define MAX_CARS 255
	gchar       buf   [ MAX_CARS +1 ];
	FILE       *fp;
	
	if( NULL != ( fp = fopen( PathNameGladeFile, "r" ))) {
		if( fgets( buf, MAX_CARS, fp ) != NULL ) {
			// g_print( "BUF= %s", buf );
			if( strncmp( buf, "<?xml version=\"1.0\"", 19 ) == 0 ) {
				BoolFileIsGlade = TRUE;
			}
		}
		fclose( fp );
	}
	
	if( FALSE == BoolFileIsGlade ) {
		wininfo_create (
			WindMain,
			_("Erreur choix de fichier GLADE !"),
			_("   Cette options impose de selectionner    "),
			  "\n",
			_("   un fichier glade valide."),
			  "\n\n",
			_("   Veuillez recommencer."),
			  "\n",
			  "");
	
	}
	return( BoolFileIsGlade );
}
// 
// 
void file_select_new_path_glade (gchar *path)
{
	gchar	*Ptr = NULL;
	gchar	*Str =  NULL;
	
	PRINT_FUNC_LF();
	// 
	// VERIF IS A GLADE FILE
	// 
	if( TRUE == Callbacks_is_glade_file( path )) {
			
		if (NULL != Config.PathGlade) {
			g_free( Config.PathGlade );
			Config.PathGlade = NULL;
		}
		if (NULL != Config.NameFileGlade) {
			g_free( Config.NameFileGlade );
			Config.NameFileGlade = NULL;
		}
		Config.PathGlade = g_strdup (path);
		if (NULL != (Ptr = strrchr (Config.PathGlade, '/'))) {
			*Ptr = '\0';
			Ptr ++;
			Config.NameFileGlade = g_strdup (Ptr);
		}
		Str = g_strdup_printf( "%s/%s", Config.PathGlade, Config.NameFileGlade );
		// gtk_button_set_label (GTK_BUTTON (GLADE_GET_OBJECT("button_name_file_glade")), Str );
		gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_name_file_glade")), Str );
		g_free( Str );	Str = NULL;

		if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
			g_print ("PATH     = %s\n", Config.PathGlade);
			g_print ("NAME     = %s\n", Config.NameFileGlade);
			g_print ("PATHNAME = %s/%s\n", Config.PathGlade, Config.NameFileGlade);
		}
		ProtoTranslate_init (path);
		Proto_init (path);
		ProtoTranslate_to_textview ();
		Proto_remove ();
	}
}
void on_button_name_file_glade_clicked( GtkButton *button, gpointer user_data )
{
	fileselect( "Choix d'un fichier Glade", FALSE, file_select_new_path_glade, Config.PathGlade );
}



void on_radiobutton_command_line_clicked( GtkButton *button, gpointer user_data )
{
	Config.BoolRadioButonGui = FALSE;
	Callbacks_set_sensitive_with_gui();
}
void on_radiobutton_gui_clicked( GtkButton *button, gpointer user_data )
{
	Config.BoolRadioButonGui = TRUE;
	Callbacks_set_sensitive_with_gui();
}

void Callbacks_set_sensitive_with_gui( void )
{
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_dossier_pixmaps")), Config.BoolRadioButonGui );
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_dossier_menu")), Config.BoolRadioButonGui );
	if( TRUE == Config.BoolRadioButonGui )
	 	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_categories_menu")), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (GLADE_GET_OBJECT("checkbutton_dossier_menu"))));
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_dossier_mime")), Config.BoolRadioButonGui );
	// 
	gtk_widget_set_sensitive( GTK_WIDGET(GLADE_GET_OBJECT("checkbutton_lib_gtk")), Config.BoolRadioButonGui );
	// 
	if( TRUE == Config.BoolRadioButonGui ) {
		if( TRUE == gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(GLADE_GET_OBJECT("checkbutton_lib_gtk")))) {
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_glade")), TRUE );
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), Config.ComboboxChoiceGlade <= CHOICE_GLADE_FILE_DEFAULT ? FALSE : TRUE );
		}
		else {
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_glade")), FALSE );
			gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), FALSE );
		}
	}
	else {
		gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("combobox_choice_glade")), FALSE );
		gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), FALSE );
	}
}




// 
// INCLUDE_PATHNAME_FILE_GLADE 	Config.IncludePathNameFileGlade
// 
void on_button_include_name_file_glade_realize( GtkWidget *widget, gpointer user_data )
{
	if( NULL == Config.IncludePathNameFileGlade ) {
		Config.IncludePathNameFileGlade = g_strdup_printf( "%s", getenv ("HOME") );
	}
	if( FALSE == libutils_test_file_exist( Config.IncludePathNameFileGlade )) {
		g_free( Config.IncludePathNameFileGlade );
		Config.IncludePathNameFileGlade  = NULL;
		Config.IncludePathNameFileGlade = g_strdup_printf( "%s", getenv ("HOME") );
		if( Config.ComboboxChoiceGlade == CHOICE_GLADE_FILE_OK )  Config.ComboboxChoiceGlade = CHOICE_GLADE_FILE_DEFAULT;
		gtk_combo_box_set_active(GTK_COMBO_BOX (VarBB.Adr_combobox_choice_glade), Config.ComboboxChoiceGlade );
	}
	gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_include_name_file_glade")), Config.IncludePathNameFileGlade );
}
void callbacks_choice_file_glade( gchar *path )
{
	// 
	// VERIF IS A GLADE FILE
	// 
	if( TRUE == Callbacks_is_glade_file( path )) {
		g_free (Config.IncludePathNameFileGlade);
		Config.IncludePathNameFileGlade = NULL;
		Config.IncludePathNameFileGlade = g_strdup (path);
		gtk_label_set_label( GTK_LABEL(GLADE_GET_OBJECT("label_include_name_file_glade")), Config.IncludePathNameFileGlade );
	}
}
void on_button_include_name_file_glade_clicked( GtkButton *button, gpointer user_data )
{
	gchar	*Path = g_strdup( Config.IncludePathNameFileGlade );
	gchar	*Ptr = strrchr( Path, '/' );
	
	if( NULL != Ptr ) {
		*Ptr = '\0';
	}

	fileselect( _("Choix d'un fichier Glade"), FALSE,  callbacks_choice_file_glade, Path );
}

// 
// 
// 
void on_combobox_choice_glade_realize( GtkWidget *widget, gpointer user_data )
{
	libcombo_alloc (GTK_COMBO_BOX (widget));
	
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Code glade cree par GTK") );
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Fichier glade cree par defaut") );
	gtk_combo_box_append_text (GTK_COMBO_BOX (widget), _("Choix d'un fichier glade") );
	gtk_combo_box_set_active(GTK_COMBO_BOX (widget), Config.ComboboxChoiceGlade );
	VarBB.Adr_combobox_choice_glade = GTK_COMBO_BOX (widget);
	
}
void on_combobox_choice_glade_changed( GtkComboBox *combobox, gpointer user_data )
{
	if( NULL != VarBB.Adr_combobox_choice_glade ) {
		Config.ComboboxChoiceGlade = gtk_combo_box_get_active (GTK_COMBO_BOX(combobox));
		gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("alignment_button_include_name_file_glade")), Config.ComboboxChoiceGlade <= CHOICE_GLADE_FILE_DEFAULT ? FALSE : TRUE );
		if( CHOICE_GLADE_FILE_OK == Config.ComboboxChoiceGlade && FALSE == libutils_test_file_exist( Config.IncludePathNameFileGlade )) {

			wininfo_create (
				WindMain,
				_("Erreur choix de fichier GLADE !"),
				_("   Cette options impose de selectionner    "),
				  "\n",
				_("   un fichier glade valide sinon la"),
				  "\n",
				_("   generation de projet validera"),
				  "\n",
				_("   l'option [ Par defaut ]. "),
				  "\n\n",
				_("   Veuillez recommencer."),
				  "\n",
				  "");
		}
	}
}

// 
// 
void on_image_gui_realize( GtkWidget *widget, gpointer user_data )
{
	gchar     *LineCommand = NULL;

	if( NULL != (LineCommand = xdg_search_data_xdg( "glade-3.png" ))) {
		gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
		g_free (LineCommand);
		LineCommand = NULL;
	}
}
void on_image_line_command_realize( GtkWidget *widget, gpointer user_data )
{
	gchar     *LineCommand = NULL;

	if( NULL != (LineCommand = xdg_search_data_xdg( "linecommand.png" ))) {
		gtk_image_set_from_file (GTK_IMAGE (widget), LineCommand);
		g_free (LineCommand);
		LineCommand = NULL;
	}
}

// 
// 
void on_entry_name_authors_realize( GtkWidget *widget, gpointer user_data )
{
	gtk_entry_set_text(GTK_ENTRY(widget), Config.NameAuthors != NULL ? Config.NameAuthors : "" );
}
void on_entry_name_authors_changed( GtkEditable *editable, gpointer user_data )
{
	if( NULL != Config.NameAuthors ) {
		g_free (Config.NameAuthors);
		Config.NameAuthors = NULL;
	}
	Config.NameAuthors = g_strdup( gtk_entry_get_text (GTK_ENTRY(GLADE_GET_OBJECT("entry_name_authors"))));
}








