 /*
 * file      : configuser.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>

#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>
#include <string.h>

#include "../lib_basebuild/libbasebuild.h"
#include "global.h"
#include "configuser.h"



typedef struct {
	gchar	**Larrbuf;
} CONF;

CONF	Conf = { NULL };

VAR_CONFIG Config = {
	FALSE,		// gboolean	BoolConfigOk
	NULL,		// gchar	*PathDest
	NULL,		// gchar	*PathGlade
	NULL,		// gchar	*NameFileGlade
	NULL,		// gchar	*NameProject
	NULL,		// gchar	*NameAuthors
	0,		// gint		WinPos_X
	0,		// gint		WinPos_Y
	750,		// gint		WinWidth
	680,		// gint		WinHeight
	0,		// gint		Page
	TRUE,		// gboolean	BoolRadioButonGui
	FALSE,		// gboolean	BoolCheckbuttonRepPO
	FALSE,		// gboolean	BoolCheckbuttonRepMANPAGE
	FALSE,		// gboolean	BoolCheckbuttonRepLIBSTATIQUE
	FALSE,		// gboolean	BoolCheckbuttonRepPIXMAPS
	FALSE,		// gboolean	BoolCheckbuttonRepMENU
	FALSE,		// gboolean	BoolCheckbuttonRepMIME
	NULL,		// gchar	*IncludePathNameFileGlade
	0,		// gint		Version_A
	0,		// gint		Version_B
	0,		// gint		Version_C
	0		// gint		ComboboxChoiceGlade
	

};


// TRUE SI p_dest EST DANS p_src SINON FALSE
//
gboolean config_new_strcmp (gchar *p_src, gchar *p_dest)
{
	gint	len_aiguille = strlen (p_dest);
	gint	len_meule;
	gint	len;
	gchar	*PtrBeginSrc = NULL;
	gchar	*PtrEndSrc = NULL;
	gchar	*PtrSrc = NULL;
	gchar	*PtrDest = p_dest;
	
	for (PtrBeginSrc = p_src; *PtrBeginSrc == ' ' || *PtrBeginSrc == '\t'; PtrBeginSrc ++);
	for (PtrEndSrc = PtrBeginSrc; *PtrEndSrc != ' ' && *PtrEndSrc != '\t'; PtrEndSrc ++);
	len_meule = PtrEndSrc - PtrBeginSrc;
	
	if (len_meule != len_aiguille) return (FALSE);
	
	len = 0;
	for (PtrSrc = PtrBeginSrc; PtrSrc < PtrEndSrc; PtrSrc ++, PtrDest ++) {
		if (*PtrSrc != *PtrDest) return (FALSE);;
		len ++;
	}
	
	return (len_meule == len ? TRUE : FALSE);
	
}
// AFFICHE LES DATAS
// 
void config_print_data (gchar *p_str)
{
	gint	len = strlen (p_str);
	g_print("%s", p_str);
	while (len < 33) {
		g_print(" ");
		len ++;
	}
	g_print("= ");
}
// RETOURNE LE NOM COMPLET DU FICHIER DE CONFIGURATION
// 
gchar *config_get_pathname (void)
{
	return ((gchar *)g_strdup_printf ("%s/%s", getenv ("HOME"), ".config/basebuild/basebuild.conf"));
}
// RETOURNE UNE DEFINITION DU FICHIER DE CONFIGURATION
// 
gchar *config_get_target (gchar *p_buf)
{
	gchar	*Str = NULL;
	gchar	*Ptr = NULL;
	
	if ((Ptr = strchr (p_buf, '=')) != NULL) {
		Ptr ++;
		while (*Ptr && (*Ptr != ' ' && *Ptr != '\t')) Ptr ++;
		Ptr ++;
		Str = g_strdup (Ptr);
		if ((Ptr = strchr (Str, '\r')) != NULL) *Ptr = '\0';
		if ((Ptr = strchr (Str, '\n')) != NULL) *Ptr = '\0';
	}
	return ((gchar *)Str);
}
// LECTURE VALEUR BOOLEAN
// 
gboolean config_get_bool (gchar *value)
{
	gchar *ptr = value;

	while (*ptr) {
		*ptr = toupper (*ptr);
		ptr++;
	}
	return (!strncmp (value, "TRUE", strlen ("TRUE")) ? TRUE : FALSE);
}
// LECTURE BOOLEAN
// 
gboolean config_read_value_bool( gchar *p_Search, gboolean *p_ValueBool )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
	
	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ] ))) {
				*p_ValueBool = config_get_bool( Ptr );
				g_free( Ptr );
				Ptr = NULL;
				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
					config_print_data( p_Search );
					g_print( "%s\n", *p_ValueBool ? "TRUE" : "FALSE" );
				}
				*Conf.Larrbuf[ Cpt ] = '\0';
				return( TRUE );	
			}
		}
	}
	return( FALSE );	
}
// LECTURE NUMERIQUE
// 
gboolean config_read_value_atoi( gchar *p_Search, gint *p_ValueAtoi, gint p_Min, gint p_Max )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
		
	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ] ))) {
				*p_ValueAtoi = atoi( Ptr );
				g_free( Ptr );
				Ptr = NULL;
				if( p_Min > -1 && *p_ValueAtoi < p_Min ) *p_ValueAtoi = p_Min;
				if( p_Max > -1 && *p_ValueAtoi > p_Max ) *p_ValueAtoi = p_Max;
				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
					config_print_data( p_Search );
					g_print( "%d\n", *p_ValueAtoi ? *p_ValueAtoi : 0 );
				}
				*Conf.Larrbuf[ Cpt ] = '\0';
				return( TRUE );
			}
		}
	}
	return( FALSE );	
}
// LECTURE PATHNAME
// 
gboolean config_read_value_path( gchar *p_Search, gchar **p_ValuePath, gchar *p_default )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
	
	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ] ))) {
				if( TRUE == libutils_test_dir_exist( Ptr )) {
					*p_ValuePath = Ptr;
				} else {
					if( NULL == p_default )	*p_ValuePath = g_strdup( getenv( "HOME" ));
					else			*p_ValuePath = g_strdup( p_default );
					g_free( Ptr );
					Ptr = NULL;
				}
			}
			else {
				if( NULL == p_default )	*p_ValuePath = g_strdup( getenv( "HOME" ));
				else			*p_ValuePath = g_strdup( p_default );
			}
			if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
				config_print_data( p_Search );
				g_print( "%s\n", *p_ValuePath ? *p_ValuePath : "" );
			}
			*Conf.Larrbuf[ Cpt ] = '\0';
			return( TRUE );	
		}
	}
	return( FALSE );	
}
// 
// 
gboolean config_read_value_str( gchar *p_Search, gchar **p_ValueStr )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
	
	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {
			if( NULL != ( Ptr = config_get_target( Conf.Larrbuf[ Cpt ]))) {
				*p_ValueStr = g_strdup( Ptr );
				g_free( Ptr );
				Ptr = NULL;
				if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
					config_print_data( p_Search );
					g_print( "%s\n", *p_ValueStr ? *p_ValueStr : "" );
				}
				*Conf.Larrbuf[ Cpt ] = '\0';
				return( TRUE );	
			}
		}
	}
	return( FALSE );	
}
// 
// CALL:
// 	config_read_value_tab( "HOURS_MONDAY", Config.HoursMonday, 4 );
// 
gboolean config_read_value_tab( gchar *p_Search, gint p_ValueTab[], gint p_max_tab )
{
	gchar	*Ptr = NULL;
	gint	Cpt;
	
	// IF NOT INIT IN TAB:
	// 	*(p_ValueTab +0) = 0;
	// 	*(p_ValueTab +1) = 0;
	// 	*(p_ValueTab +2) = 0;
	// 	*(p_ValueTab +3) = 0;
	
	for( Cpt = 0; Conf.Larrbuf[ Cpt ]; Cpt++ ) {
		
		// Si commentaire ou ligne vide alors ligne suivante
		if( *Conf.Larrbuf[ Cpt ] == '#' || *Conf.Larrbuf[ Cpt ] == '\0') continue;
		
		if( TRUE == config_new_strcmp( Conf.Larrbuf[ Cpt ], p_Search )) {

			if( TRUE == OptionsCommandLine.BoolVerboseMode )
				config_print_data( p_Search );

			if( NULL != (Ptr = strchr( Conf.Larrbuf[ Cpt ], '=' ))) {
				
				gchar	**LarrbufLine = NULL;
				gint	Indice;
				
				// POINTEUR SUR LA PREMIERE OCCURANCE
				Ptr ++;
				while( *Ptr == ' ' || *Ptr == '\t' ) Ptr ++;
				
				// *Ptr IS VALID ?
				if( *Ptr != '\0' ) {
					
					// HOURS_MONDAY                  = 435 690 720 975
					// HOURS_SATURDAY                = 0 0 0 0
					LarrbufLine = g_strsplit( Ptr, " ", 0 );
				
					// INDICE: 0 .. p_max_tab
					for( Indice = 0; LarrbufLine[ Indice ] && Indice < p_max_tab; Indice ++ ) {
					
						*(p_ValueTab +Indice) = (gint)atoi( LarrbufLine[ Indice ] );
					
						if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
							g_print ("%04d (%02d:%02d)  ",
								*(p_ValueTab +Indice),
								*(p_ValueTab +Indice) / 60,
								*(p_ValueTab +Indice) % 60
								);
						}
					}
				
					g_strfreev( LarrbufLine );
					LarrbufLine = NULL;
				}
			}
			
			if( TRUE == OptionsCommandLine.BoolVerboseMode )
				g_print( "\n" );
			
			*Conf.Larrbuf[ Cpt ] = '\0';
			return( TRUE );	
		}
	}
	return( FALSE );	
}
// 	
// 	
gboolean config_open_conf_file( gchar *p_PathNameConfig )
{
	size_t 		SizeFile;
	gchar		*Buffer = NULL;
	FILE		*fp = NULL;
	
	Conf.Larrbuf = NULL;
	if(( SizeFile = libutils_get_size_file( p_PathNameConfig )) > 0 ) {
		if( NULL != ( fp = fopen( p_PathNameConfig, "r" ))) {
			Buffer = (gchar *)g_malloc0( sizeof(gchar) * ( SizeFile +10 ));
			SizeFile = fread( Buffer, SizeFile, 1, fp );
			fclose( fp );
			Conf.Larrbuf = g_strsplit( Buffer, "\n", 0 );
			g_free( Buffer );
			Buffer = NULL;
			return( TRUE );
		}
	}
	return( FALSE );
}
// 	
// 	
void config_close_conf_file( void )
{
	g_strfreev( Conf.Larrbuf );
	Conf.Larrbuf = NULL;
}
// LECTURE DU FICHIER DE CONFIGURATION
// 
void config_read (void)
{
	gchar	*PathNameConfig = config_get_pathname ();	// HOME /.config/basebuild/basebuild.conf
	
	if( TRUE == OptionsCommandLine.BoolVerboseMode ) {
		g_print ("\n------------------------------------------------------------------------\n" );
		g_print ("%s\n", PathNameConfig);
		g_print ("------------------------------------------------------------------------\n" );
	}
	
	// IF NOT EXIST CONFIG-FILE
	if( FALSE == libutils_test_file_exist( PathNameConfig )) {
		// GET PATHNAME
		gchar	*StrDir = g_strdup( PathNameConfig );
		// GET PATH
		gchar	*Ptr = strrchr( StrDir, '/' );
		
		// NOW StrDir IS PATH
		Ptr ++;
		*Ptr = '\0';
		// CREATION DU DOSSIER
		g_mkdir_with_parents (StrDir, 0700);
		// FREE MEM
		g_free( StrDir );	StrDir = Ptr = NULL;
		// CREATE CONFIG-FILE
		config_save ();
	}
	
	if( TRUE == config_open_conf_file( PathNameConfig )) {
		
		// READ ATOI
		// 
		config_read_value_atoi( "WIN_POS_X",			&Config.WinPos_X,		0,	-1 );
		config_read_value_atoi( "WIN_POS_Y",			&Config.WinPos_Y,		0,	-1 );
		config_read_value_atoi( "WIN_WIDTH",			&Config.WinWidth,		-1,	-1 );
		config_read_value_atoi( "WIN_HEIGHT",			&Config.WinHeight,		-1,	-1 );
		config_read_value_atoi( "PAGE_NOTEBOOK",		&Config.Page,			-1,	-1 );
		config_read_value_atoi( "VERSION_A",			&Config.Version_A,		-1,	-1 );
		config_read_value_atoi( "VERSION_B",			&Config.Version_B,      	-1,	-1 );
		config_read_value_atoi( "VERSION_C",			&Config.Version_C,		-1,	-1 );
		config_read_value_atoi( "COMBOBOX_CHOICE_GLADE",	&Config.ComboboxChoiceGlade,	CHOICE_GLADE_FILE_NONE,	CHOICE_GLADE_FILE_OK );
		
		// READ BOOL
		// 
		config_read_value_bool( "BoolRadioButonGui",		&Config.BoolRadioButonGui );
		config_read_value_bool( "BoolCheckbuttonRepPO",		&Config.BoolCheckbuttonRepPO );
		config_read_value_bool( "BoolCheckbuttonRepMANPAGE",	&Config.BoolCheckbuttonRepMANPAGE );
		config_read_value_bool( "BoolCheckbuttonRepLIBSTATIQUE",&Config.BoolCheckbuttonRepLIBSTATIQUE );
		config_read_value_bool( "BoolCheckbuttonRepPIXMAPS",	&Config.BoolCheckbuttonRepPIXMAPS );
		config_read_value_bool( "BoolCheckbuttonRepMENU",	&Config.BoolCheckbuttonRepMENU );
		config_read_value_bool( "BoolCheckbuttonRepMIME",	&Config.BoolCheckbuttonRepMIME );
		
		// READ PATH
		// 
		config_read_value_path( "PATH",				&Config.PathDest,	NULL );
		config_read_value_path( "PATH_GLADE",			&Config.PathGlade,	NULL );
		
		// READ STRING
		// 
		config_read_value_str( "NAME_PROJECT",			&Config.NameProject );
		config_read_value_str( "NAME_AUTHORS",			&Config.NameAuthors );
		config_read_value_str( "NAMEFILE_GLADE",		&Config.NameFileGlade );
		config_read_value_str( "INCLUDE_PATHNAME_FILE_GLADE",	&Config.IncludePathNameFileGlade );
		
		config_close_conf_file();
	}
	g_free( PathNameConfig );
	PathNameConfig = NULL;
}
//  SAUVEGARDE DU FICHIER DE CONFIGURATION
// 
void config_save (void)
{
	gchar	*PathNameConfig = config_get_pathname ();	// HOME /.config/basebuild/basebuild.conf
	FILE	*fp;
	
	if (NULL != (fp = fopen (PathNameConfig, "w"))) {
		fprintf (fp,   "############################################################################\n");
		fprintf (fp,   "## Fichier de configuration pour : %s\n", PACKAGE_STRING);
		fprintf (fp,   "##--------------------------------------------------------------------------\n");
		fprintf (fp,   "## File of configuration to : %s\n", PACKAGE_STRING);
		fprintf (fp,   "############################################################################\n");
		
		fprintf (fp, "\n");
		fprintf (fp, "PATH                          = %s\n", Config.PathDest == NULL ? getenv ("HOME") : Config.PathDest);
		fprintf (fp, "PATH_GLADE                    = %s\n", Config.PathGlade == NULL ? "" : Config.PathGlade);
		fprintf (fp, "NAMEFILE_GLADE                = %s\n", Config.NameFileGlade == NULL ? "" : Config.NameFileGlade);
		fprintf (fp, "NAME_PROJECT                  = %s\n", Config.NameProject == NULL ? "NameProject" : Config.NameProject);
		fprintf (fp, "NAME_AUTHORS                  = %s\n", Config.NameAuthors == NULL ? "" : Config.NameAuthors);
		fprintf (fp, "WIN_POS_X                     = %d\n", Config.WinPos_X);
		fprintf (fp, "WIN_POS_Y                     = %d\n", Config.WinPos_Y);
		fprintf (fp, "WIN_WIDTH                     = %d\n", Config.WinWidth);
		fprintf (fp, "WIN_HEIGHT                    = %d\n", Config.WinHeight);
		fprintf (fp, "PAGE_NOTEBOOK                 = %d\n", Config.Page);
		fprintf (fp, "VERSION_A                     = %d\n", Config.Version_A);
		fprintf (fp, "VERSION_B                     = %d\n", Config.Version_B);
		fprintf (fp, "VERSION_C                     = %d\n", Config.Version_C);
		fprintf (fp, "BoolRadioButonGui             = %s\n", Config.BoolRadioButonGui == TRUE ? "TRUE" : "FALSE" );
		
		fprintf (fp, "BoolCheckbuttonRepPO          = %s\n", Config.BoolCheckbuttonRepPO == TRUE ? "TRUE" : "FALSE" );
		fprintf (fp, "BoolCheckbuttonRepMANPAGE     = %s\n", Config.BoolCheckbuttonRepMANPAGE == TRUE ? "TRUE" : "FALSE" );
		fprintf (fp, "BoolCheckbuttonRepLIBSTATIQUE = %s\n", Config.BoolCheckbuttonRepLIBSTATIQUE == TRUE ? "TRUE" : "FALSE" );
		fprintf (fp, "BoolCheckbuttonRepPIXMAPS     = %s\n", Config.BoolCheckbuttonRepPIXMAPS == TRUE ? "TRUE" : "FALSE" );
		fprintf (fp, "BoolCheckbuttonRepMENU        = %s\n", Config.BoolCheckbuttonRepMENU == TRUE ? "TRUE" : "FALSE" );
		fprintf (fp, "BoolCheckbuttonRepMIME        = %s\n", Config.BoolCheckbuttonRepMIME == TRUE ? "TRUE" : "FALSE" );

		fprintf (fp, "INCLUDE_PATHNAME_FILE_GLADE   = %s\n", Config.IncludePathNameFileGlade );
		fprintf (fp, "COMBOBOX_CHOICE_GLADE         = %d\n", Config.ComboboxChoiceGlade ); 
		
		fprintf (fp, "\n");
		fclose (fp);
	}
	g_free( PathNameConfig );
	PathNameConfig = NULL;
}
// LIBERATION MEMOIRE
// 
void config_remove (void)
{
	g_free( Config.PathDest );			Config.PathDest = NULL;
	g_free( Config.PathGlade);			Config.PathGlade = NULL;
	g_free( Config.NameFileGlade);			Config.NameFileGlade = NULL;
	g_free( Config.NameProject);			Config.NameProject = NULL;
	g_free( Config.NameAuthors);			Config.NameAuthors = NULL;
	g_free( Config.IncludePathNameFileGlade);	Config.IncludePathNameFileGlade = NULL;
}































