 /*
 * file      : def_src.c
 * project   : BaseBuild
 * with      : Gtk-2
 *
 * copyright : (C) 2010 - 2012 by Claude Bulin
 *
 * BaseBuild - Creation d'une base de programmation en langage C de type GNU avec les autotools
 * GNU General Public License
 * 
 * This file is part of BASEBUILD.
 * 
 * BASEBUILD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * at your option) any later version.
 * 
 * BASEBUILD is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with BASEBUILD.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#ifdef ENABLE_NLS
	#include <libintl.h>
	#define _(String) gettext (String)
#endif

#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>

#include <ctype.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <stdlib.h>
#include <string.h>

#include "configuser.h"
#include "build.h"
#include "def_src.h"
#include "callbacks.h"
#include "global.h"



enum
{
	DEFSRC_NAME_REP = 0,
	DEFSRC_NAME_REP_EDITABLE,
	DEFSRC_NAME_EXEC,
	DEFSRC_NAME_EXEC_EDITABLE,
	DEFSRC_TOTAL_COLUMN
};

typedef struct {
	
	GtkListStore      *Adr_List_Store;
	GtkTreeModel      *Adr_Tree_Model;
	GtkWidget         *Adr_scroll;
	GtkTreeSelection  *Adr_Line_Selected;
	GtkWidget	  *Adr_TreeView;
	
} VAR_DEFSRC;

VAR_DEFSRC VarDefSrc;




// RENVOIE TRUE SI LA SELECTION EST ACTIVE
// 
gboolean DefSrc_is_selected (void)
{
	GtkTreeModel	*model = NULL;
	return (NULL == gtk_tree_selection_get_selected_rows (VarDefSrc.Adr_Line_Selected, &model) ? FALSE : TRUE);
}

// RENVOIE TRUE SI LA SELECTION EST LA PREMIERE LIGNE SINON FALSE
// 
gboolean DefSrc_is_src (void)
{
	GtkTreeIter	iter;
	GtkTreeModel	*model = NULL;
	GList		*BeginList = NULL;
	GList		*list = NULL;
	GtkTreePath	*path;
	gint		Num = 0;
	gboolean	BoolSel = FALSE;

	// RECUP. DE LA LIGNE EN SELECTION POUR DESTRUCTION	
	model = gtk_tree_view_get_model (GTK_TREE_VIEW(VarDefSrc.Adr_TreeView));
	if ((BeginList = gtk_tree_selection_get_selected_rows (VarDefSrc.Adr_Line_Selected, &model))) {
		list = g_list_first (BeginList);
		while (list) {
			if ((path = list->data)) {
				gtk_tree_model_get_iter (model, &iter, path);
				gtk_tree_model_get (VarDefSrc.Adr_Tree_Model, &iter, DEFSRC_NAME_REP_EDITABLE, &BoolSel, -1);
				Num ++;
			}
			list = g_list_next (list);
		}
	}
	return (BoolSel);
}
// MISE A JOUR DES CHAMPS
// 
void DefSrc_set_flag_buttons (void)
{
	gtk_widget_set_sensitive (GTK_WIDGET(GLADE_GET_OBJECT("button_clean_line_src")), DefSrc_is_src () && DefSrc_is_selected ());
}
// ALLOCATION DE LA LISTE DES ENTREES SOURCES: Nom et Executable
// 
GList *DefSrc_get_list (void)
{
	VAR_BUILD_SRC	*New = NULL;
	GList		*List = NULL;
	gboolean	valid;
	GtkTreeIter	iter;
	
	valid = gtk_tree_model_get_iter_first (VarDefSrc.Adr_Tree_Model, &iter);
	while (valid) {
		New = (VAR_BUILD_SRC *)g_malloc0 (sizeof (VAR_BUILD_SRC));
		gtk_tree_model_get (VarDefSrc.Adr_Tree_Model, &iter, DEFSRC_NAME_REP, &New->Name, -1);
		gtk_tree_model_get (VarDefSrc.Adr_Tree_Model, &iter, DEFSRC_NAME_EXEC, &New->Exec, -1);
		New->PathName          = NULL;
		New->GstrSrcMakefileAm = NULL;
		List = g_list_append (List, New);
		valid = gtk_tree_model_iter_next (VarDefSrc.Adr_Tree_Model, &iter);
	}
	return ((GList *)List);
}
// SUPPRESSION DE LA LISTE DES ENTREES SOURCES: Nom et Executable
// 
GList *DefSrc_remove_list (GList *p_List)
{
	GList		*List = NULL;
	VAR_BUILD_SRC	*New = NULL;
	
	List = g_list_first (p_List);
	while (List) {
		if (NULL != (New = (VAR_BUILD_SRC *)List->data)) {
			if (NULL != New->GstrSrcMakefileAm) {
				g_string_free (New->GstrSrcMakefileAm, TRUE);
				New->GstrSrcMakefileAm = NULL;
			}
			if (NULL != New->PathName) {
				g_free (New->PathName);
				New->PathName = NULL;
			}
			if (NULL != New->Name) {
				g_free (New->Name);
				New->Name = NULL;
			}
			if (NULL != New->Exec) {
				g_free (New->Exec);
				New->Exec = NULL;
			}
			g_free (New);
			New = List->data = NULL;
		}
		List = g_list_next (List);
	}
	g_list_free (List);
	List = NULL;
	return ((GList *)NULL);
}
// VERIFIE SI UN NOM DE DOSSIER EST DUPPLIQUE + CONFORMITE DES NOMS
// 
gint DefSrc_is_dupply (void)
{
	GList		*List = NULL;
	GList		*ListOne = NULL;
	GList		*ListTwo = NULL;
	gint		NumErrorName = 0;
	gint		NumErrorDupply = 0;
	VAR_BUILD_SRC	*New = NULL;
	VAR_BUILD_SRC	*New2 = NULL;
	
	// CONSTRUCTION DE LA LISTE
	List = DefSrc_get_list ();
	
	// VERIFIE SI DUPPLICATION ET CONFORMITE DES NOMS DOSSIERS ET EXECUTABLES
	ListOne = g_list_first (List);
	while (ListOne) {
		if (NULL != (New = (VAR_BUILD_SRC *)ListOne->data)) {
			
			// TEST CONFORMITE NOM DU DOSSIER
			gchar	*Ptr = New->Name;
			while (*Ptr) {
				// g_print("g_ascii_isalnum (%c) = %s\n", *Ptr, g_ascii_isalnum (*Ptr) ? "TRUE" : "FALSE");
				if (FALSE == g_ascii_isalnum (*Ptr) && *Ptr != '_') {
					NumErrorName = 1;
					// g_print("\tERROR\n");
				}
				Ptr++;
			}
			// TEST CONFORMITE NOM DE L EXECUTABLE
			Ptr = New->Exec;
			while (*Ptr) {
				// g_print("g_ascii_isalnum (%c) = %s\n", *Ptr, g_ascii_isalnum (*Ptr) ? "TRUE" : "FALSE");
				if (FALSE == g_ascii_isalnum (*Ptr) && *Ptr != '_') {
					NumErrorName = 1;
					// g_print("\tERROR\n");
				}
				Ptr++;
			}
			// TEST DUPPLICATION
			ListTwo = g_list_next (ListOne);
			while (ListTwo) {
				if (NULL != (New2 = (VAR_BUILD_SRC *)ListTwo->data)) {
					if (0 == strcmp (New->Name, New2->Name)) {
						NumErrorDupply = 2;
						break;
					}
				}
				ListTwo = g_list_next (ListTwo);
			}
		}
		ListOne = g_list_next (ListOne);
	}
	
	// DESTRUCTION DE LA LISTE
	List = DefSrc_remove_list (List);
	
	return (NumErrorName + NumErrorDupply);
}
// DESTRUCTION DE LA LIGNE EN SELECTION
// 
void on_button_clean_line_src_clicked (GtkButton *button, gpointer user_data)
{
	gboolean	valid;
	GtkTreeIter	iter;
	GtkTreeIter	OldIter;
	GtkTreeModel	*model = NULL;
	GList		*BeginList = NULL;
	GList		*list = NULL;
	GtkTreePath	*path;

	// RECUP. DE LA LIGNE EN SELECTION POUR DESTRUCTION
	model = gtk_tree_view_get_model (GTK_TREE_VIEW(VarDefSrc.Adr_TreeView));
	if ((BeginList = gtk_tree_selection_get_selected_rows (VarDefSrc.Adr_Line_Selected, &model))) {
		list = g_list_first (BeginList);
		while (list) {
			if ((path = list->data)) {
				gtk_tree_model_get_iter (model, &iter, path);
				gtk_list_store_remove (VarDefSrc.Adr_List_Store, &iter);
				break;
			}
			list = g_list_next (list);
		}
		// SI ITER PLUS VALIDE
		if (FALSE == gtk_list_store_iter_is_valid (VarDefSrc.Adr_List_Store, &iter)) {
			// RECUP DU DERNIER ITER VALIDE DANS LA LISTE
			valid = gtk_tree_model_get_iter_first (VarDefSrc.Adr_Tree_Model, &iter);
			OldIter = iter;
			while (valid) {
				OldIter = iter;
				valid = gtk_tree_model_iter_next (VarDefSrc.Adr_Tree_Model, &iter);
			}
			iter = OldIter;
		}
		// SI ITER EST CORRECT ALORS NOUVELLE SELECTION
		if (TRUE == gtk_list_store_iter_is_valid (VarDefSrc.Adr_List_Store, &iter)) {
			gtk_tree_selection_select_iter (VarDefSrc.Adr_Line_Selected, &iter);
		}
	}
}
// AFFICHAGE DANS LE TREEVIEW
// 
void DefSrc_set_name (gchar *NameSrc, gboolean BoolModifSrc, gchar *NameExec, gboolean BoolModifExec)
{
	GtkTreeIter		iter;

	gtk_list_store_append (VarDefSrc.Adr_List_Store, &iter);
	gtk_list_store_set (VarDefSrc.Adr_List_Store, &iter,
				DEFSRC_NAME_REP,		NameSrc,
				DEFSRC_NAME_REP_EDITABLE,	BoolModifSrc,
				DEFSRC_NAME_EXEC,		NameExec,
				DEFSRC_NAME_EXEC_EDITABLE,	BoolModifExec,
				-1);
	
	// 
	if (FALSE == BoolModifSrc)
		gtk_tree_selection_select_iter (VarDefSrc.Adr_Line_Selected, &iter);
}
// AJOUT D UNE LIGNE DANS LE TREEVIEW
// 
void on_button_add_line_src_clicked (GtkButton *button, gpointer user_data)
{
	gchar	*NameLib = Callbacks_get_name_project();
	
	DefSrc_set_name ("src", TRUE, NameLib, TRUE);
	g_free( NameLib );	NameLib = NULL;
}
// EDITION DANS LE TREEVIEW
// 
static void DefSrc_cell_edited_file (GtkCellRendererText *cell, const gchar *path_string, const gchar *new_text, gpointer data)
{
	GtkTreeIter	 iter;
	gint		 column = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cell), "column"));
	GtkTreeModel	*model = (GtkTreeModel *)data;
	GtkTreePath	*path = gtk_tree_path_new_from_string (path_string);
	gchar		*old_text;
	
	gtk_tree_model_get_iter (model, &iter, path);
	if (column == DEFSRC_NAME_REP || column == DEFSRC_NAME_EXEC) {
		
		gchar *NewText = NULL;
		
		gtk_tree_model_get (model, &iter, column, &old_text, -1);
		if( NULL == new_text || '\0' == *new_text )
			NewText = g_strdup( old_text );
		else	NewText = g_strdup( new_text );
		gtk_list_store_set (GTK_LIST_STORE (model),
					&iter,
					column,
					NewText,
					-1);
		g_free (NewText);
		NewText = NULL;
		g_free (old_text);
		old_text = NULL;
	}
	gtk_tree_path_free (path);
}
// ACTION SOURIS
// 
void DefSrc_changed_selection_row_file (GtkTreeSelection *selection, gpointer data)
{
	VarDefSrc.Adr_Line_Selected = selection;
	DefSrc_set_flag_buttons ();
}
// INIT DES COLONNES
// 
void DefSrc_add_columns (GtkTreeView *treeview)
{
	GtkTreeModel      *model = gtk_tree_view_get_model (treeview);
	GtkCellRenderer   *renderer;
	GtkTreeViewColumn *column;

	/* SIGNAL : Ligne actuellement selectionnee 'changed'
	*/
	VarDefSrc.Adr_Line_Selected = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	g_signal_connect(G_OBJECT(VarDefSrc.Adr_Line_Selected),
			 "changed",
                   	 G_CALLBACK(DefSrc_changed_selection_row_file),
                   	 "1");
	
	// DEFSRC_NAME_REP
	renderer = gtk_cell_renderer_text_new ();
	g_signal_connect (renderer, "edited", G_CALLBACK (DefSrc_cell_edited_file), model);
	g_object_set (renderer, "xalign", 0.0, NULL);
	g_object_set_data (G_OBJECT (renderer), "column", (gint *)DEFSRC_NAME_REP);
	column = gtk_tree_view_column_new_with_attributes (_("Nom du dossier source"),
						renderer,
						"markup", DEFSRC_NAME_REP,
						"editable", DEFSRC_NAME_REP_EDITABLE,
						NULL);
	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
						GTK_TREE_VIEW_COLUMN_FIXED);
	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 400);
	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
	gtk_tree_view_append_column (treeview, column);
	
	// DEFSRC_NAME_EXEC
	renderer = gtk_cell_renderer_text_new ();
	g_signal_connect (renderer, "edited", G_CALLBACK (DefSrc_cell_edited_file), model);
	g_object_set (renderer, "xalign", 0.0, NULL);
	g_object_set_data (G_OBJECT (renderer), "column", (gint *)DEFSRC_NAME_EXEC);
	column = gtk_tree_view_column_new_with_attributes (_("Nom de l'executable"),
						renderer,
						"markup", DEFSRC_NAME_EXEC,
						"editable", DEFSRC_NAME_EXEC_EDITABLE,
						NULL);
	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column),
						GTK_TREE_VIEW_COLUMN_FIXED);
	// gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 110);
	gtk_tree_view_column_set_alignment (GTK_TREE_VIEW_COLUMN (column), 0.5);
	gtk_tree_view_append_column (treeview, column);
	
	// DEFSRC_TOTAL_COLUMN
}
// INIT DU TREEVIEW
// 
void on_scrolledwindow_dir_def_realize (GtkWidget *widget, gpointer user_data)
{
	GtkTreeModel	*model;
	GtkWidget	*treeview;
	GtkListStore	*store;
	gchar		*NameLib = Callbacks_get_name_project();

	// PRINT_FUNC_LF();

	VarDefSrc.Adr_scroll = widget;
	VarDefSrc.Adr_List_Store =
	store = gtk_list_store_new (DEFSRC_TOTAL_COLUMN,	// Nombre total de colonnes
				    G_TYPE_STRING,		// Name
				    G_TYPE_BOOLEAN,		// COLUMN_FILE_EDITABLE
				    G_TYPE_STRING,		// Commentaire
				    G_TYPE_BOOLEAN,		// COLUMN_FILE_EDITABLE
				    G_TYPE_POINTER		// Pointeur sur structure
				    );
	VarDefSrc.Adr_Tree_Model = 
	model = GTK_TREE_MODEL (store);

	VarDefSrc.Adr_TreeView =
	treeview = gtk_tree_view_new_with_model (model);
	gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview), TRUE);

	g_object_unref (model);
	gtk_container_add (GTK_CONTAINER (widget), treeview);

	/* add columns to the tree view */
	DefSrc_add_columns (GTK_TREE_VIEW (treeview));
			
	gtk_widget_show_all (widget);
	
	if( NULL == NameLib ) {
		NameLib = g_strdup( Config.NameProject );
	}
	DefSrc_set_name ("src", FALSE, NameLib, TRUE);
	g_free( NameLib );	NameLib = NULL;
}

void on_notebook_dossiers_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, gpointer user_data)
{
	if (TRUE == Config.BoolConfigOk) {
		Config.Page = page_num;
	}
}














